@@ -16,7 +16,7 @@ markov_msm <-
               debug = FALSE,
               ...)
 {
-    stopifnot(requireNamespace("deSolve", quietly=TRUE))
+    stopifnot(requireNamespace("lsoda", quietly=TRUE))
     call <- match.call()
     inherits <- function(x, ...)
         base::inherits(x, ...) ||
@@ -122,7 +122,7 @@ markov_msm <-
         rownames(m) <- colnames(m) <- names(coef(objects))
         m
     }
-    dp <- function(t, y, parms, ...) {
+    dp <- function(t, y, ...) {
         P <- matrix(y[1:(nstates*nobs)],nstates,nobs) # only one state vector per individual
         Pu <- array(y[nstates*nobs+1:(nstates*ncoef*nobs)],c(nstates,ncoef,nobs))
         Q <- array(0, c(nstates, nstates, nobs))
@@ -207,7 +207,7 @@ markov_msm <-
                              rep(0,3*nobs*nstates+3*nobs*nstates*ncoef+nobs*nstates*ntr))
             else
                 c(rep(init,nobs),rep(0,2*nobs*nstates+2*nobs*nstates*ncoef))
-    res <- deSolve::ode(y = init, times = t, func = dp, method=method, atol=atol, rtol=rtol,
+    res <- lsoda::ode(y = init, times = t, func = dp, parms=NULL, atol=atol, rtol=rtol,
                ...)
     P <- array(res[,1+1:(nstates*nobs)],c(nt,nstates,nobs))
     Pu <- array(res[,1+nobs*nstates+1:(nobs*nstates*ncoef)],c(nt,nstates,ncoef,nobs))
@@ -398,16 +398,18 @@ as.data.frame.markov_msm <- function(x, row.names=NULL, optional=FALSE,
     y$time <- as.numeric(attr(y$time,"levels"))[y$time]
     out <- cbind(y,out)
     if (ci) {
+        fix = function(Bound,Point) ifelse((is.na(Bound) | is.nan(Bound)) &
+                                           (Point==0 | Point == 1), Point, Bound)
         tmp <- surv.confint(out$P,out$seP, conf.type=P.conf.type, min.value=P.range[1], max.value=P.range[2])
-        out$P.lower=tmp$lower
-        out$P.upper=tmp$upper
+        out$P.lower=fix(tmp$lower,out$P)
+        out$P.upper=fix(tmp$upper,out$P)
         tmp <- surv.confint(out$L,out$seL, conf.type=L.conf.type, min.value=L.range[1], max.value=L.range[2])
-        out$L.lower=tmp$lower
-        out$L.upper=tmp$upper
+        out$L.lower=fix(tmp$lower,out$L)
+        out$L.upper=fix(tmp$upper,out$L)
         if (!is.null(x$costs)) {
             tmp <- surv.confint(out$C,out$seC, conf.type=C.conf.type, min.value=C.range[1], max.value=C.range[2])
-            out$C.lower=tmp$lower
-            out$C.upper=tmp$upper
+            out$C.lower=fix(tmp$lower,out$C)
+            out$C.upper=fix(tmp$upper,out$C)
         }
     }
     newdata <- as.data.frame(x$newdata[as.numeric(out$obs), , drop=FALSE])
