@@ -6,7 +6,7 @@ library(rstpm2)
 slow <- FALSE
 
 expect_eps <- function(expr, value, eps=1e-7)
-    expect_lt(max(abs(expr-value)),eps)
+    testthat::expect_lt(max(abs(expr-value)),eps)
 
 context("stpm2")
 ##
@@ -17,14 +17,11 @@ test_that("base", {
 })
 test_that("offset", {
     skip_on_cran()
-    brcancer2 = transform(brcancer, o=1)
-    fit <- stpm2(Surv(rectime,censrec==1)~hormon+offset(o),data=brcancer2)
-    expect_eps(coef(fit)[1], -8.256669, 1e-5)
-    expect_eps(coef(fit)[2], -0.361403, 1e-5)
-    fit <- stpm2(Surv(rectime,censrec==1)~hormon+offset(o),data=brcancer2,
-                 control=list(optimiser="NelderMead"))
-    expect_eps(coef(fit)[1], -8.2550422, 1e-5)
-    expect_eps(coef(fit)[2], -0.3608321, 1e-5)
+    brcancer2 = transform(brcancer, one=1)
+    fit0 <- stpm2(Surv(rectime,censrec==1)~hormon,data=brcancer2)
+    fit1 <- stpm2(Surv(rectime,censrec==1)~hormon+offset(one),data=brcancer2)
+    expect_eps(coef(fit1)[1], coef(fit0)[1]-1, 1e-5)
+    expect_eps(coef(fit1)[2], coef(fit0)[2], 1e-5)
 })
 test_that("NelderMead", {
     fit <- stpm2(Surv(rectime,censrec==1)~hormon,data=brcancer,
